# Type a Page (Sample)

instructions

## Instructions hide

Please re-type the content of the PDF page (a link is provided below). Please note,

- You will need a PDF viewer. If you do not already have a PDF viewer, you can download Adobe Reader.
- Please use your best judgement for including hand-written notes.
- If you encounter something that's unrecognizable or unclear, do your best, then include three exclamation marks (!!!) to indicate that a problem occurred.
- Please use exact capitalization spacing and punctuation.
- In general, do not worry about formatting. Type each paragraph without carriage returns, and include a single carriage return between paragraphs.
- If you encounter tables, type each row on the same line using the pipe (|) to separate columns.
- If the page appears too complex (contains more than 1,000 words or is too difficult to decipher), please reject the job.

The page is displayed below. If you prefer, you can use a link to the page to save the file or open it in a separate window (using right-click and Save Link As or Save Target As).

Type the content of the page here.

If you have any comments or questions, please include them here.